@@ -38,35 +38,33 @@
 #' library(dplyr, warn.conflicts = FALSE)
 #'
 #' cm <- tibble::tribble(
-#'         ~USUBJID, ~CMGRPID,  ~CMREFID,            ~CMDECOD,
-#'   "BP40257-1001",     "14", "1192056",       "PARACETAMOL",
-#'   "BP40257-1001",     "18", "2007001",        "SOLUMEDROL",
-#'   "BP40257-1002",     "19", "2791596",    "SPIRONOLACTONE"
+#'   ~USUBJID, ~CMGRPID, ~CMREFID, ~CMDECOD,
+#'   "BP40257-1001", "14", "1192056", "PARACETAMOL",
+#'   "BP40257-1001", "18", "2007001", "SOLUMEDROL",
+#'   "BP40257-1002", "19", "2791596", "SPIRONOLACTONE"
 #' )
 #' facm <- tibble::tribble(
-#'         ~USUBJID, ~FAGRPID,  ~FAREFID,   ~FATESTCD, ~FASTRESC,
-#'   "BP40257-1001",      "1", "1192056",  "CMATC1CD",       "N",
-#'   "BP40257-1001",      "1", "1192056",  "CMATC2CD",     "N02",
-#'   "BP40257-1001",      "1", "1192056",  "CMATC3CD",    "N02B",
-#'   "BP40257-1001",      "1", "1192056",  "CMATC4CD",   "N02BE",
-#'
-#'   "BP40257-1001",      "1", "2007001",  "CMATC1CD",       "D",
-#'   "BP40257-1001",      "1", "2007001",  "CMATC2CD",     "D10",
-#'   "BP40257-1001",      "1", "2007001",  "CMATC3CD",    "D10A",
-#'   "BP40257-1001",      "1", "2007001",  "CMATC4CD",   "D10AA",
-#'   "BP40257-1001",      "2", "2007001",  "CMATC1CD",       "D",
-#'   "BP40257-1001",      "2", "2007001",  "CMATC2CD",     "D07",
-#'   "BP40257-1001",      "2", "2007001",  "CMATC3CD",    "D07A",
-#'   "BP40257-1001",      "2", "2007001",  "CMATC4CD",   "D07AA",
-#'   "BP40257-1001",      "3", "2007001",  "CMATC1CD",       "H",
-#'   "BP40257-1001",      "3", "2007001",  "CMATC2CD",     "H02",
-#'   "BP40257-1001",      "3", "2007001",  "CMATC3CD",    "H02A",
-#'   "BP40257-1001",      "3", "2007001",  "CMATC4CD",   "H02AB",
-#'
-#'   "BP40257-1002",      "1", "2791596",  "CMATC1CD",       "C",
-#'   "BP40257-1002",      "1", "2791596",  "CMATC2CD",     "C03",
-#'   "BP40257-1002",      "1", "2791596",  "CMATC3CD",    "C03D",
-#'   "BP40257-1002",      "1", "2791596",  "CMATC4CD",   "C03DA"
+#'   ~USUBJID, ~FAGRPID, ~FAREFID, ~FATESTCD, ~FASTRESC,
+#'   "BP40257-1001", "1", "1192056", "CMATC1CD", "N",
+#'   "BP40257-1001", "1", "1192056", "CMATC2CD", "N02",
+#'   "BP40257-1001", "1", "1192056", "CMATC3CD", "N02B",
+#'   "BP40257-1001", "1", "1192056", "CMATC4CD", "N02BE",
+#'   "BP40257-1001", "1", "2007001", "CMATC1CD", "D",
+#'   "BP40257-1001", "1", "2007001", "CMATC2CD", "D10",
+#'   "BP40257-1001", "1", "2007001", "CMATC3CD", "D10A",
+#'   "BP40257-1001", "1", "2007001", "CMATC4CD", "D10AA",
+#'   "BP40257-1001", "2", "2007001", "CMATC1CD", "D",
+#'   "BP40257-1001", "2", "2007001", "CMATC2CD", "D07",
+#'   "BP40257-1001", "2", "2007001", "CMATC3CD", "D07A",
+#'   "BP40257-1001", "2", "2007001", "CMATC4CD", "D07AA",
+#'   "BP40257-1001", "3", "2007001", "CMATC1CD", "H",
+#'   "BP40257-1001", "3", "2007001", "CMATC2CD", "H02",
+#'   "BP40257-1001", "3", "2007001", "CMATC3CD", "H02A",
+#'   "BP40257-1001", "3", "2007001", "CMATC4CD", "H02AB",
+#'   "BP40257-1002", "1", "2791596", "CMATC1CD", "C",
+#'   "BP40257-1002", "1", "2791596", "CMATC2CD", "C03",
+#'   "BP40257-1002", "1", "2791596", "CMATC3CD", "C03D",
+#'   "BP40257-1002", "1", "2791596", "CMATC4CD", "C03DA"
 #' )
 #'
 #' cm %>%
@@ -92,7 +90,7 @@ derive_vars_transposed <- function(dataset,
 
   dataset_transposed <- dataset_merge %>%
     filter_if(filter) %>%
-    spread(key = !!key_var, value = !!value_var)
+    pivot_wider(names_from = !!key_var, values_from = !!value_var)
 
   left_join(dataset, dataset_transposed, by = vars2chr(by_vars))
 }
@@ -124,35 +122,33 @@ derive_vars_transposed <- function(dataset,
 #'
 #' @examples
 #' cm <- tibble::tribble(
-#'         ~USUBJID, ~CMGRPID,  ~CMREFID,            ~CMDECOD,
-#'   "BP40257-1001",     "14", "1192056",       "PARACETAMOL",
-#'   "BP40257-1001",     "18", "2007001",        "SOLUMEDROL",
-#'   "BP40257-1002",     "19", "2791596",    "SPIRONOLACTONE"
+#'   ~USUBJID, ~CMGRPID, ~CMREFID, ~CMDECOD,
+#'   "BP40257-1001", "14", "1192056", "PARACETAMOL",
+#'   "BP40257-1001", "18", "2007001", "SOLUMEDROL",
+#'   "BP40257-1002", "19", "2791596", "SPIRONOLACTONE"
 #' )
 #' facm <- tibble::tribble(
-#'         ~USUBJID, ~FAGRPID,  ~FAREFID,   ~FATESTCD, ~FASTRESC,
-#'   "BP40257-1001",      "1", "1192056",  "CMATC1CD",       "N",
-#'   "BP40257-1001",      "1", "1192056",  "CMATC2CD",     "N02",
-#'   "BP40257-1001",      "1", "1192056",  "CMATC3CD",    "N02B",
-#'   "BP40257-1001",      "1", "1192056",  "CMATC4CD",   "N02BE",
-#'
-#'   "BP40257-1001",      "1", "2007001",  "CMATC1CD",       "D",
-#'   "BP40257-1001",      "1", "2007001",  "CMATC2CD",     "D10",
-#'   "BP40257-1001",      "1", "2007001",  "CMATC3CD",    "D10A",
-#'   "BP40257-1001",      "1", "2007001",  "CMATC4CD",   "D10AA",
-#'   "BP40257-1001",      "2", "2007001",  "CMATC1CD",       "D",
-#'   "BP40257-1001",      "2", "2007001",  "CMATC2CD",     "D07",
-#'   "BP40257-1001",      "2", "2007001",  "CMATC3CD",    "D07A",
-#'   "BP40257-1001",      "2", "2007001",  "CMATC4CD",   "D07AA",
-#'   "BP40257-1001",      "3", "2007001",  "CMATC1CD",       "H",
-#'   "BP40257-1001",      "3", "2007001",  "CMATC2CD",     "H02",
-#'   "BP40257-1001",      "3", "2007001",  "CMATC3CD",    "H02A",
-#'   "BP40257-1001",      "3", "2007001",  "CMATC4CD",   "H02AB",
-#'
-#'   "BP40257-1002",      "1", "2791596",  "CMATC1CD",       "C",
-#'   "BP40257-1002",      "1", "2791596",  "CMATC2CD",     "C03",
-#'   "BP40257-1002",      "1", "2791596",  "CMATC3CD",    "C03D",
-#'   "BP40257-1002",      "1", "2791596",  "CMATC4CD",   "C03DA"
+#'   ~USUBJID, ~FAGRPID, ~FAREFID, ~FATESTCD, ~FASTRESC,
+#'   "BP40257-1001", "1", "1192056", "CMATC1CD", "N",
+#'   "BP40257-1001", "1", "1192056", "CMATC2CD", "N02",
+#'   "BP40257-1001", "1", "1192056", "CMATC3CD", "N02B",
+#'   "BP40257-1001", "1", "1192056", "CMATC4CD", "N02BE",
+#'   "BP40257-1001", "1", "2007001", "CMATC1CD", "D",
+#'   "BP40257-1001", "1", "2007001", "CMATC2CD", "D10",
+#'   "BP40257-1001", "1", "2007001", "CMATC3CD", "D10A",
+#'   "BP40257-1001", "1", "2007001", "CMATC4CD", "D10AA",
+#'   "BP40257-1001", "2", "2007001", "CMATC1CD", "D",
+#'   "BP40257-1001", "2", "2007001", "CMATC2CD", "D07",
+#'   "BP40257-1001", "2", "2007001", "CMATC3CD", "D07A",
+#'   "BP40257-1001", "2", "2007001", "CMATC4CD", "D07AA",
+#'   "BP40257-1001", "3", "2007001", "CMATC1CD", "H",
+#'   "BP40257-1001", "3", "2007001", "CMATC2CD", "H02",
+#'   "BP40257-1001", "3", "2007001", "CMATC3CD", "H02A",
+#'   "BP40257-1001", "3", "2007001", "CMATC4CD", "H02AB",
+#'   "BP40257-1002", "1", "2791596", "CMATC1CD", "C",
+#'   "BP40257-1002", "1", "2791596", "CMATC2CD", "C03",
+#'   "BP40257-1002", "1", "2791596", "CMATC3CD", "C03D",
+#'   "BP40257-1002", "1", "2791596", "CMATC4CD", "C03DA"
 #' )
 #'
 #' derive_vars_atc(cm, facm)
@@ -172,5 +168,5 @@ derive_vars_atc <- function(dataset,
       filter = str_detect(FATESTCD, "^CMATC[1-4](CD)?$")
     ) %>%
     select(-starts_with("FA")) %>%
-    rename_at(vars(starts_with("CMATC")), ~str_remove(.x, "^CM"))
+    rename_at(vars(starts_with("CMATC")), ~ str_remove(.x, "^CM"))
 }
